'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function noop() {}

function assign(tar, src) {
	for (var k in src) tar[k] = src[k];
	return tar;
}

function appendNode(node, target) {
	target.appendChild(node);
}

function insertNode(node, target, anchor) {
	target.insertBefore(node, anchor);
}

function detachNode(node) {
	node.parentNode.removeChild(node);
}

function reinsertBetween(before, after, target) {
	while (before.nextSibling && before.nextSibling !== after) {
		target.appendChild(before.parentNode.removeChild(before.nextSibling));
	}
}

function reinsertChildren(parent, target) {
	while (parent.firstChild) target.appendChild(parent.firstChild);
}

function reinsertAfter(before, target) {
	while (before.nextSibling) target.appendChild(before.nextSibling);
}

function createElement(name) {
	return document.createElement(name);
}

function createText(data) {
	return document.createTextNode(data);
}

function createComment() {
	return document.createComment('');
}

function addListener(node, event, handler) {
	node.addEventListener(event, handler, false);
}

function removeListener(node, event, handler) {
	node.removeEventListener(event, handler, false);
}

function setAttribute(node, attribute, value) {
	node.setAttribute(attribute, value);
}

function setAttributes(node, attributes) {
	for (var key in attributes) {
		if (key in node) {
			node[key] = attributes[key];
		} else {
			if (attributes[key] === undefined) removeAttribute(node, key);
			else setAttribute(node, key, attributes[key]);
		}
	}
}

function removeAttribute(node, attribute) {
	node.removeAttribute(attribute);
}

function setStyle(node, key, value) {
	node.style.setProperty(key, value);
}

function destroyBlock(block, lookup) {
	block.u();
	block.d();
	lookup[block.key] = null;
}

function outroAndDestroyBlock(block, lookup) {
	block.o(function() {
		destroyBlock(block, lookup);
	});
}

function getSpreadUpdate(levels, updates) {
	var update = {};

	var to_null_out = {};
	var accounted_for = {};

	var i = levels.length;
	while (i--) {
		var o = levels[i];
		var n = updates[i];

		if (n) {
			for (var key in o) {
				if (!(key in n)) to_null_out[key] = 1;
			}

			for (var key in n) {
				if (!accounted_for[key]) {
					update[key] = n[key];
					accounted_for[key] = 1;
				}
			}

			levels[i] = n;
		} else {
			for (var key in o) {
				accounted_for[key] = 1;
			}
		}
	}

	for (var key in to_null_out) {
		if (!(key in update)) update[key] = undefined;
	}

	return update;
}

function blankObject() {
	return Object.create(null);
}

function destroy(detach) {
	this.destroy = noop;
	this.fire('destroy');
	this.set = this.get = noop;

	if (detach !== false) this._fragment.u();
	this._fragment.d();
	this._fragment = this._state = null;
}

function _differs(a, b) {
	return a != a ? b == b : a !== b || ((a && typeof a === 'object') || typeof a === 'function');
}

function dispatchObservers(component, group, changed, newState, oldState) {
	for (var key in group) {
		if (!changed[key]) continue;

		var newValue = newState[key];
		var oldValue = oldState[key];

		var callbacks = group[key];
		if (!callbacks) continue;

		for (var i = 0; i < callbacks.length; i += 1) {
			var callback = callbacks[i];
			if (callback.__calling) continue;

			callback.__calling = true;
			callback.call(component, newValue, oldValue);
			callback.__calling = false;
		}
	}
}

function fire(eventName, data) {
	var handlers =
		eventName in this._handlers && this._handlers[eventName].slice();
	if (!handlers) return;

	for (var i = 0; i < handlers.length; i += 1) {
		handlers[i].call(this, data);
	}
}

function get(key) {
	return key ? this._state[key] : this._state;
}

function init(component, options) {
	component._observers = { pre: blankObject(), post: blankObject() };
	component._handlers = blankObject();
	component._bind = options._bind;

	component.options = options;
	component.root = options.root || component;
	component.store = component.root.store || options.store;
}

function observe(key, callback, options) {
	var group = options && options.defer
		? this._observers.post
		: this._observers.pre;

	(group[key] || (group[key] = [])).push(callback);

	if (!options || options.init !== false) {
		callback.__calling = true;
		callback.call(this, this._state[key]);
		callback.__calling = false;
	}

	return {
		cancel: function() {
			var index = group[key].indexOf(callback);
			if (~index) group[key].splice(index, 1);
		}
	};
}

function on(eventName, handler) {
	if (eventName === 'teardown') return this.on('destroy', handler);

	var handlers = this._handlers[eventName] || (this._handlers[eventName] = []);
	handlers.push(handler);

	return {
		cancel: function() {
			var index = handlers.indexOf(handler);
			if (~index) handlers.splice(index, 1);
		}
	};
}

function set(newState) {
	this._set(assign({}, newState));
	if (this.root._lock) return;
	this.root._lock = true;
	callAll(this.root._beforecreate);
	callAll(this.root._oncreate);
	callAll(this.root._aftercreate);
	this.root._lock = false;
}

function _set(newState) {
	var oldState = this._state,
		changed = {},
		dirty = false;

	for (var key in newState) {
		if (this._differs(newState[key], oldState[key])) changed[key] = dirty = true;
	}
	if (!dirty) return;

	this._state = assign(assign({}, oldState), newState);
	this._recompute(changed, this._state);
	if (this._bind) this._bind(changed, this._state);

	if (this._fragment) {
		dispatchObservers(this, this._observers.pre, changed, this._state, oldState);
		this._fragment.p(changed, this._state);
		dispatchObservers(this, this._observers.post, changed, this._state, oldState);
	}
}

function callAll(fns) {
	while (fns && fns.length) fns.shift()();
}

function _mount(target, anchor) {
	this._fragment[this._fragment.i ? 'i' : 'm'](target, anchor || null);
}

function _unmount() {
	if (this._fragment) this._fragment.u();
}

var proto = {
	destroy: destroy,
	get: get,
	fire: fire,
	observe: observe,
	on: on,
	set: set,
	teardown: destroy,
	_recompute: noop,
	_set: _set,
	_mount: _mount,
	_unmount: _unmount,
	_differs: _differs
};

/* src/Close.html generated by Svelte v1.60.3 */
function create_main_fragment$1(component, state) {
	var button;

	function click_handler(event) {
		component.fire('click');
	}

	return {
		c: function create() {
			button = createElement("button");
			button.innerHTML = "<span aria-hidden=\"true\">×</span>";
			this.h();
		},

		h: function hydrate() {
			addListener(button, "click", click_handler);
			button.type = "button";
			button.className = "close";
			setAttribute(button, "aria-label", "Close");
		},

		m: function mount(target, anchor) {
			insertNode(button, target, anchor);
		},

		p: noop,

		u: function unmount() {
			detachNode(button);
		},

		d: function destroy$$1() {
			removeListener(button, "click", click_handler);
		}
	};
}

function Close(options) {
	init(this, options);
	this._state = assign({}, options.data);

	this._fragment = create_main_fragment$1(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(Close.prototype, proto);

/* src/Alert.html generated by Svelte v1.60.3 */
// TODO handle fade transition when dismissing

function data() {
  return {
    class: '',
    color: 'success',
    isOpen: true,
    dismissible: false
  };
}

function create_main_fragment(component, state) {
	var if_block_anchor;

	var if_block = (state.isOpen) && create_if_block(component, state);

	return {
		c: function create() {
			if (if_block) if_block.c();
			if_block_anchor = createComment();
		},

		m: function mount(target, anchor) {
			if (if_block) if_block.m(target, anchor);
			insertNode(if_block_anchor, target, anchor);
		},

		p: function update(changed, state) {
			if (state.isOpen) {
				if (if_block) {
					if_block.p(changed, state);
				} else {
					if_block = create_if_block(component, state);
					if_block.c();
					if_block.m(if_block_anchor.parentNode, if_block_anchor);
				}
			} else if (if_block) {
				if_block.u();
				if_block.d();
				if_block = null;
			}
		},

		u: function unmount() {
			if (if_block) if_block.u();
			detachNode(if_block_anchor);
		},

		d: function destroy$$1() {
			if (if_block) if_block.d();
		}
	};
}

// (3:4) {{#if dismissible}}
function create_if_block_1(component, state) {

	var close = new Close({
		root: component.root
	});

	close.on("click", function(event) {
		component.set({ isOpen: false });
	});

	return {
		c: function create() {
			close._fragment.c();
		},

		m: function mount(target, anchor) {
			close._mount(target, anchor);
		},

		u: function unmount() {
			close._unmount();
		},

		d: function destroy$$1() {
			close.destroy(false);
		}
	};
}

// (1:0) {{#if isOpen}}
function create_if_block(component, state) {
	var div, text, slot_content_default = component._slotted.default, slot_content_default_before, div_class_value;

	var if_block = (state.dismissible) && create_if_block_1(component, state);

	return {
		c: function create() {
			div = createElement("div");
			if (if_block) if_block.c();
			text = createText("\n    ");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "alert alert-" + state.color + (state.dismissible ? ' alert-dismissible' : '') + " " + state.class;
			setAttribute(div, "role", "alert");
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);
			if (if_block) if_block.m(div, null);
			appendNode(text, div);

			if (slot_content_default) {
				appendNode(slot_content_default_before || (slot_content_default_before = createComment()), div);
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if (state.dismissible) {
				if (!if_block) {
					if_block = create_if_block_1(component, state);
					if_block.c();
					if_block.m(div, text);
				}
			} else if (if_block) {
				if_block.u();
				if_block.d();
				if_block = null;
			}

			if ((changed.color || changed.dismissible || changed.class) && div_class_value !== (div_class_value = "alert alert-" + state.color + (state.dismissible ? ' alert-dismissible' : '') + " " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);
			if (if_block) if_block.u();

			if (slot_content_default) {
				reinsertAfter(slot_content_default_before, slot_content_default);
			}
		},

		d: function destroy$$1() {
			if (if_block) if_block.d();
		}
	};
}

function Alert(options) {
	init(this, options);
	this._state = assign(data(), options.data);

	this._slotted = options.slots || {};

	if (!options.root) {
		this._oncreate = [];
		this._beforecreate = [];
		this._aftercreate = [];
	}

	this.slots = {};

	this._fragment = create_main_fragment(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);

		this._lock = true;
		callAll(this._beforecreate);
		callAll(this._oncreate);
		callAll(this._aftercreate);
		this._lock = false;
	}
}

assign(Alert.prototype, proto);

/* src/Badge.html generated by Svelte v1.60.3 */
function data$1() {
  return {
    class: '',
    color: 'default',
    pill: false
  };
}

function create_main_fragment$2(component, state) {
	var span, slot_content_default = component._slotted.default, span_class_value;

	return {
		c: function create() {
			span = createElement("span");
			this.h();
		},

		h: function hydrate() {
			span.className = span_class_value = "badge badge-" + state.color + (state.pill ? ' badge-pill' : '') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(span, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, span);
			}
		},

		p: function update(changed, state) {
			if ((changed.color || changed.pill || changed.class) && span_class_value !== (span_class_value = "badge badge-" + state.color + (state.pill ? ' badge-pill' : '') + " " + state.class)) {
				span.className = span_class_value;
			}
		},

		u: function unmount() {
			detachNode(span);

			if (slot_content_default) {
				reinsertChildren(span, slot_content_default);
			}
		},

		d: noop
	};
}

function Badge(options) {
	init(this, options);
	this._state = assign(data$1(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$2(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(Badge.prototype, proto);

/* src/Breadcrumb.html generated by Svelte v1.60.3 */
function data$2() {
  return {
    class: ''
  }
}

function create_main_fragment$3(component, state) {
	var ol, slot_content_default = component._slotted.default, ol_class_value;

	return {
		c: function create() {
			ol = createElement("ol");
			this.h();
		},

		h: function hydrate() {
			ol.className = ol_class_value = "breadcrumb " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(ol, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, ol);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && ol_class_value !== (ol_class_value = "breadcrumb " + state.class)) {
				ol.className = ol_class_value;
			}
		},

		u: function unmount() {
			detachNode(ol);

			if (slot_content_default) {
				reinsertChildren(ol, slot_content_default);
			}
		},

		d: noop
	};
}

function Breadcrumb(options) {
	init(this, options);
	this._state = assign(data$2(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$3(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(Breadcrumb.prototype, proto);

/* src/BreadcrumbItem.html generated by Svelte v1.60.3 */
function data$3() {
  return {
    active: false,
    class: ''
  }
}

function create_main_fragment$4(component, state) {
	var li, slot_content_default = component._slotted.default, li_class_value;

	function click_handler(event) {
		component.fire("click", event);
	}

	return {
		c: function create() {
			li = createElement("li");
			this.h();
		},

		h: function hydrate() {
			addListener(li, "click", click_handler);
			li.className = li_class_value = "breadcrumb-item" + (state.active ? ' active' : '') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(li, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, li);
			}
		},

		p: function update(changed, state) {
			if ((changed.active || changed.class) && li_class_value !== (li_class_value = "breadcrumb-item" + (state.active ? ' active' : '') + " " + state.class)) {
				li.className = li_class_value;
			}
		},

		u: function unmount() {
			detachNode(li);

			if (slot_content_default) {
				reinsertChildren(li, slot_content_default);
			}
		},

		d: function destroy$$1() {
			removeListener(li, "click", click_handler);
		}
	};
}

function BreadcrumbItem(options) {
	init(this, options);
	this._state = assign(data$3(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$4(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(BreadcrumbItem.prototype, proto);

/* src/Button.html generated by Svelte v1.60.3 */
function data$4() {
  return {
    active: false,
    block: false,
    class: '',
    color: 'secondary',
    outline: false,
    size: null
  }
}

function create_main_fragment$5(component, state) {
	var button, slot_content_default = component._slotted.default;

	function click_handler(event) {
		component.fire("click", event);
	}

	var button_levels = [
		{ class: "btn btn" + (state.outline ? '-outline' : '') + "-" + state.color + (state.size ? ` btn-${state.size}` : '') + (state.block ? ' btn-block' : '') + (state.active ? ' active' : '') + (state.disabled ? ' disabled' : '') + " " + state.class },
		state.props
	];

	var button_data = {};
	for (var i = 0; i < button_levels.length; i += 1) {
		button_data = assign(button_data, button_levels[i]);
	}

	return {
		c: function create() {
			button = createElement("button");
			this.h();
		},

		h: function hydrate() {
			addListener(button, "click", click_handler);
			setAttributes(button, button_data);
		},

		m: function mount(target, anchor) {
			insertNode(button, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, button);
			}
		},

		p: function update(changed, state) {
			setAttributes(button, getSpreadUpdate(button_levels, [
				changed.outline || changed.color || changed.size || changed.block || changed.active || changed.disabled || changed.class && { class: "btn btn" + (state.outline ? '-outline' : '') + "-" + state.color + (state.size ? ` btn-${state.size}` : '') + (state.block ? ' btn-block' : '') + (state.active ? ' active' : '') + (state.disabled ? ' disabled' : '') + " " + state.class },
				changed.props && state.props
			]));
		},

		u: function unmount() {
			detachNode(button);

			if (slot_content_default) {
				reinsertChildren(button, slot_content_default);
			}
		},

		d: function destroy$$1() {
			removeListener(button, "click", click_handler);
		}
	};
}

function Button(options) {
	init(this, options);
	this._state = assign(data$4(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$5(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(Button.prototype, proto);

/* src/ButtonGroup.html generated by Svelte v1.60.3 */
function data$5() {
  return {
    class: ''
  }
}

function create_main_fragment$6(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "" + (state.size ? `btn-group-${state.size} ` : '') + (state.vertical ? 'btn-group-vertical' : 'btn-group') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.size || changed.vertical || changed.class) && div_class_value !== (div_class_value = "" + (state.size ? `btn-group-${state.size} ` : '') + (state.vertical ? 'btn-group-vertical' : 'btn-group') + " " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function ButtonGroup(options) {
	init(this, options);
	this._state = assign(data$5(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$6(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(ButtonGroup.prototype, proto);

/* src/ButtonToolbar.html generated by Svelte v1.60.3 */
function data$6() {
  return {
    class: ''
  }
}

function create_main_fragment$7(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "btn-toolbar " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && div_class_value !== (div_class_value = "btn-toolbar " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function ButtonToolbar(options) {
	init(this, options);
	this._state = assign(data$6(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$7(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(ButtonToolbar.prototype, proto);

/* src/Card.html generated by Svelte v1.60.3 */
function data$7() {
  return {
    block: false,
    class: '',
    inverse: false,
    outline: false
  }
}

function create_main_fragment$8(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "card" + (state.inverse ? ' card-inverse' : '') + (state.block ? ' card-body' : '') + (state.color ? ` ${state.outline ? 'border' : 'bg'}-${state.color}` : '') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.inverse || changed.block || changed.color || changed.outline || changed.class) && div_class_value !== (div_class_value = "card" + (state.inverse ? ' card-inverse' : '') + (state.block ? ' card-body' : '') + (state.color ? ` ${state.outline ? 'border' : 'bg'}-${state.color}` : '') + " " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function Card(options) {
	init(this, options);
	this._state = assign(data$7(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$8(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(Card.prototype, proto);

/* src/CardBody.html generated by Svelte v1.60.3 */
function data$8() {
  return {
    class: ''
  }
}

function create_main_fragment$9(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "card-body " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && div_class_value !== (div_class_value = "card-body " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function CardBody(options) {
	init(this, options);
	this._state = assign(data$8(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$9(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(CardBody.prototype, proto);

/* src/CardColumns.html generated by Svelte v1.60.3 */
function data$9() {
  return {
    class: ''
  }
}

function create_main_fragment$10(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "card-columns " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && div_class_value !== (div_class_value = "card-columns " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function CardColumns(options) {
	init(this, options);
	this._state = assign(data$9(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$10(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(CardColumns.prototype, proto);

/* src/CardDeck.html generated by Svelte v1.60.3 */
function data$10() {
  return {
    class: ''
  }
}

function create_main_fragment$11(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "card-deck " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && div_class_value !== (div_class_value = "card-deck " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function CardDeck(options) {
	init(this, options);
	this._state = assign(data$10(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$11(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(CardDeck.prototype, proto);

/* src/CardFooter.html generated by Svelte v1.60.3 */
function data$11() {
  return {
    class: ''
  }
}

function create_main_fragment$12(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "card-footer " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && div_class_value !== (div_class_value = "card-footer " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function CardFooter(options) {
	init(this, options);
	this._state = assign(data$11(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$12(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(CardFooter.prototype, proto);

/* src/CardGroup.html generated by Svelte v1.60.3 */
function data$12() {
  return {
    class: ''
  }
}

function create_main_fragment$13(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "card-group " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && div_class_value !== (div_class_value = "card-group " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function CardGroup(options) {
	init(this, options);
	this._state = assign(data$12(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$13(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(CardGroup.prototype, proto);

/* src/CardHeader.html generated by Svelte v1.60.3 */
function data$13() {
  return {
    class: ''
  }
}

function create_main_fragment$14(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "card-header " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && div_class_value !== (div_class_value = "card-header " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function CardHeader(options) {
	init(this, options);
	this._state = assign(data$13(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$14(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(CardHeader.prototype, proto);

/* src/CardImgOverlay.html generated by Svelte v1.60.3 */
function data$14() {
  return {
    class: ''
  }
}

function create_main_fragment$15(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "card-img-overlay " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && div_class_value !== (div_class_value = "card-img-overlay " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function CardImgOverlay(options) {
	init(this, options);
	this._state = assign(data$14(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$15(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(CardImgOverlay.prototype, proto);

/* src/CardSubtitle.html generated by Svelte v1.60.3 */
function data$15() {
  return {
    class: ''
  }
}

function create_main_fragment$16(component, state) {
	var h6, slot_content_default = component._slotted.default, h6_class_value;

	return {
		c: function create() {
			h6 = createElement("h6");
			this.h();
		},

		h: function hydrate() {
			h6.className = h6_class_value = "card-subtitle " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(h6, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, h6);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && h6_class_value !== (h6_class_value = "card-subtitle " + state.class)) {
				h6.className = h6_class_value;
			}
		},

		u: function unmount() {
			detachNode(h6);

			if (slot_content_default) {
				reinsertChildren(h6, slot_content_default);
			}
		},

		d: noop
	};
}

function CardSubtitle(options) {
	init(this, options);
	this._state = assign(data$15(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$16(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(CardSubtitle.prototype, proto);

/* src/CardText.html generated by Svelte v1.60.3 */
function data$16() {
  return {
    class: ''
  }
}

function create_main_fragment$17(component, state) {
	var p, slot_content_default = component._slotted.default, p_class_value;

	return {
		c: function create() {
			p = createElement("p");
			this.h();
		},

		h: function hydrate() {
			p.className = p_class_value = "card-text " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(p, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, p);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && p_class_value !== (p_class_value = "card-text " + state.class)) {
				p.className = p_class_value;
			}
		},

		u: function unmount() {
			detachNode(p);

			if (slot_content_default) {
				reinsertChildren(p, slot_content_default);
			}
		},

		d: noop
	};
}

function CardText(options) {
	init(this, options);
	this._state = assign(data$16(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$17(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(CardText.prototype, proto);

/* src/CardTitle.html generated by Svelte v1.60.3 */
function data$17() {
  return {
    class: ''
  }
}

function create_main_fragment$18(component, state) {
	var h4, slot_content_default = component._slotted.default, h4_class_value;

	return {
		c: function create() {
			h4 = createElement("h4");
			this.h();
		},

		h: function hydrate() {
			h4.className = h4_class_value = "card-title " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(h4, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, h4);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && h4_class_value !== (h4_class_value = "card-title " + state.class)) {
				h4.className = h4_class_value;
			}
		},

		u: function unmount() {
			detachNode(h4);

			if (slot_content_default) {
				reinsertChildren(h4, slot_content_default);
			}
		},

		d: noop
	};
}

function CardTitle(options) {
	init(this, options);
	this._state = assign(data$17(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$18(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(CardTitle.prototype, proto);

/* src/Col.html generated by Svelte v1.60.3 */
const widths = ['xs', 'sm', 'md', 'lg', 'xl'];

function isObject(value) {
  const type = typeof value;
  return value != null && (type == 'object' || type == 'function');
}

const getColumnSizeClass = (isXs, colWidth, colSize) => {
  if (colSize === true || colSize === '') {
    return isXs ? 'col' : `col-${colWidth}`;
  } else if (colSize === 'auto') {
    return isXs ? 'col-auto' : `col-${colWidth}-auto`;
  }

  return isXs ? `col-${colSize}` : `col-${colWidth}-${colSize}`;
};

function classes(widths, xs, sm, md, lg, xl) {
  const colClasses = [];
  const props = {
    xs,
    sm,
    md,
    lg,
    xl
  };

  widths.forEach((colWidth, i) => {
    let columnProp = props[colWidth];

    if (!i && columnProp === undefined) {
      columnProp = true;
    }

    if (!columnProp) {
      return;
    }

    const isXs = !i;
    let colClass;

    if (isObject(columnProp)) {
      const colSizeInterfix = isXs ? '-' : `-${colWidth}-`;
      colClass = getColumnSizeClass(isXs, colWidth, columnProp.size);

      if (columnProp.size || columnProp.size === '') colClasses.push(colClass);
      if (columnProp.push) colClasses.push(`push${colSizeInterfix}${columnProp.push}`);
      if (columnProp.pull) colClasses.push(`pull${colSizeInterfix}${columnProp.pull}`);
      if (columnProp.offset) colClasses.push(`offset${colSizeInterfix}${columnProp.offset}`);
    } else {
      colClass = getColumnSizeClass(isXs, colWidth, columnProp);
      colClasses.push(colClass);
    }
  });
  
  return colClasses.join(' ');
}

function data$18() {
  return {
    class: '',
    widths
  }
}

function create_main_fragment$19(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "" + state.classes + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.classes || changed.class) && div_class_value !== (div_class_value = "" + state.classes + " " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function Col(options) {
	init(this, options);
	this._state = assign(data$18(), options.data);
	this._recompute({ widths: 1, xs: 1, sm: 1, md: 1, lg: 1, xl: 1 }, this._state);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$19(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(Col.prototype, proto);

Col.prototype._recompute = function _recompute(changed, state) {
	if (changed.widths || changed.xs || changed.sm || changed.md || changed.lg || changed.xl) {
		if (this._differs(state.classes, (state.classes = classes(state.widths, state.xs, state.sm, state.md, state.lg, state.xl)))) changed.classes = true;
	}
};

/* src/Container.html generated by Svelte v1.60.3 */
function data$19() {
  return {
    class: '',
    fluid: false
  }
}

function create_main_fragment$20(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "container" + (state.fluid ? '-fluid' : '') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.fluid || changed.class) && div_class_value !== (div_class_value = "container" + (state.fluid ? '-fluid' : '') + " " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function Container(options) {
	init(this, options);
	this._state = assign(data$19(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$20(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(Container.prototype, proto);

/* src/Dropdown.html generated by Svelte v1.60.3 */
// TODO manage open logic internally to this component, if possible
// TODO support closing from click outside
function data$20() {
  return {
    class: '',
    dropup: false,
    open: false
  }
}

function create_main_fragment$21(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "dropdown" + (state.dropup ? ' dropup' : '') + (state.open ? ' show' : '') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.dropup || changed.open || changed.class) && div_class_value !== (div_class_value = "dropdown" + (state.dropup ? ' dropup' : '') + (state.open ? ' show' : '') + " " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function Dropdown(options) {
	init(this, options);
	this._state = assign(data$20(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$21(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(Dropdown.prototype, proto);

/* src/DropdownDivider.html generated by Svelte v1.60.3 */
function data$21() {
  return {
    class: ''
  }
}

function create_main_fragment$22(component, state) {
	var div, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "dropdown-divider " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);
		},

		p: function update(changed, state) {
			if ((changed.class) && div_class_value !== (div_class_value = "dropdown-divider " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);
		},

		d: noop
	};
}

function DropdownDivider(options) {
	init(this, options);
	this._state = assign(data$21(), options.data);

	this._fragment = create_main_fragment$22(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(DropdownDivider.prototype, proto);

/* src/DropdownHeader.html generated by Svelte v1.60.3 */
function data$22() {
  return {
    class: ''
  }
}

function create_main_fragment$23(component, state) {
	var h6, slot_content_default = component._slotted.default, h6_class_value;

	return {
		c: function create() {
			h6 = createElement("h6");
			this.h();
		},

		h: function hydrate() {
			h6.className = h6_class_value = "dropdown-header " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(h6, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, h6);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && h6_class_value !== (h6_class_value = "dropdown-header " + state.class)) {
				h6.className = h6_class_value;
			}
		},

		u: function unmount() {
			detachNode(h6);

			if (slot_content_default) {
				reinsertChildren(h6, slot_content_default);
			}
		},

		d: noop
	};
}

function DropdownHeader(options) {
	init(this, options);
	this._state = assign(data$22(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$23(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(DropdownHeader.prototype, proto);

/* src/DropdownItem.html generated by Svelte v1.60.3 */
function data$23() {
  return {
    class: '',
    disabled: false
  }
}

function create_main_fragment$24(component, state) {
	var button, slot_content_default = component._slotted.default, button_class_value;

	return {
		c: function create() {
			button = createElement("button");
			this.h();
		},

		h: function hydrate() {
			button.className = button_class_value = "dropdown-item" + (state.disabled ? ' disabled' : '') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(button, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, button);
			}
		},

		p: function update(changed, state) {
			if ((changed.disabled || changed.class) && button_class_value !== (button_class_value = "dropdown-item" + (state.disabled ? ' disabled' : '') + " " + state.class)) {
				button.className = button_class_value;
			}
		},

		u: function unmount() {
			detachNode(button);

			if (slot_content_default) {
				reinsertChildren(button, slot_content_default);
			}
		},

		d: noop
	};
}

function DropdownItem(options) {
	init(this, options);
	this._state = assign(data$23(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$24(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(DropdownItem.prototype, proto);

/* src/DropdownMenu.html generated by Svelte v1.60.3 */
function data$24() {
  return {
    class: '',
    right: false
  }
}

function create_main_fragment$25(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "dropdown-menu" + (state.right ? ' dropdown-menu-right' : '') + " " + state.class;
			div.tabIndex = "-1";
			setAttribute(div, "role", "menu");
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.right || changed.class) && div_class_value !== (div_class_value = "dropdown-menu" + (state.right ? ' dropdown-menu-right' : '') + " " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function DropdownMenu(options) {
	init(this, options);
	this._state = assign(data$24(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$25(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(DropdownMenu.prototype, proto);

/* src/Form.html generated by Svelte v1.60.3 */
function data$25() {
  return {
    class: '',
    inline: false
  }
}

function create_main_fragment$26(component, state) {
	var form, slot_content_default = component._slotted.default, form_class_value;

	return {
		c: function create() {
			form = createElement("form");
			this.h();
		},

		h: function hydrate() {
			form.className = form_class_value = "" + (state.inline ? 'form-inline' : '') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(form, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, form);
			}
		},

		p: function update(changed, state) {
			if ((changed.inline || changed.class) && form_class_value !== (form_class_value = "" + (state.inline ? 'form-inline' : '') + " " + state.class)) {
				form.className = form_class_value;
			}
		},

		u: function unmount() {
			detachNode(form);

			if (slot_content_default) {
				reinsertChildren(form, slot_content_default);
			}
		},

		d: noop
	};
}

function Form(options) {
	init(this, options);
	this._state = assign(data$25(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$26(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(Form.prototype, proto);

/* src/FormFeedback.html generated by Svelte v1.60.3 */
function data$26() {
  return {
    class: ''
  }
}

function create_main_fragment$27(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "form-control-feedback " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && div_class_value !== (div_class_value = "form-control-feedback " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function FormFeedback(options) {
	init(this, options);
	this._state = assign(data$26(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$27(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(FormFeedback.prototype, proto);

/* src/FormGroup.html generated by Svelte v1.60.3 */
function data$27() {
  return {
    check: false,
    class: '',
    color: null,
    disabled: false,
    row: false
  }
}

function create_main_fragment$28(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "" + (state.color ? `has-${state.color}` : '') + (state.row ? ' row' : '') + (state.check ? ' form-check' : ' form-group') + (state.check && state.disabled ? ' disabled' : '') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.color || changed.row || changed.check || changed.disabled || changed.class) && div_class_value !== (div_class_value = "" + (state.color ? `has-${state.color}` : '') + (state.row ? ' row' : '') + (state.check ? ' form-check' : ' form-group') + (state.check && state.disabled ? ' disabled' : '') + " " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function FormGroup(options) {
	init(this, options);
	this._state = assign(data$27(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$28(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(FormGroup.prototype, proto);

/* src/FormText.html generated by Svelte v1.60.3 */
function data$28() {
  return {
    class: '',
    color: null,
    inline: false
  }
}

function create_main_fragment$29(component, state) {
	var small, slot_content_default = component._slotted.default, small_class_value;

	return {
		c: function create() {
			small = createElement("small");
			this.h();
		},

		h: function hydrate() {
			small.className = small_class_value = "" + (!state.inline ? 'form-text' : '') + (state.color ? ` text-${state.color}` : '') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(small, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, small);
			}
		},

		p: function update(changed, state) {
			if ((changed.inline || changed.color || changed.class) && small_class_value !== (small_class_value = "" + (!state.inline ? 'form-text' : '') + (state.color ? ` text-${state.color}` : '') + " " + state.class)) {
				small.className = small_class_value;
			}
		},

		u: function unmount() {
			detachNode(small);

			if (slot_content_default) {
				reinsertChildren(small, slot_content_default);
			}
		},

		d: noop
	};
}

function FormText(options) {
	init(this, options);
	this._state = assign(data$28(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$29(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(FormText.prototype, proto);

/* src/Icon.html generated by Svelte v1.60.3 */
function data$29() {
  return {
    border: false,
    class: '',
    fixedWidth: false,
    flip: false,
    inverse: false,
    pulse: false,
    rotate: false,
    size: false,
    spin: false,
    stack: false
  }
}

function create_main_fragment$30(component, state) {
	var i, i_class_value;

	return {
		c: function create() {
			i = createElement("i");
			this.h();
		},

		h: function hydrate() {
			i.className = i_class_value = "fa fa-" + state.name + (state.size ? ' fa-' + state.size : '') + (state.spin ? ' fa-spin' : '') + (state.pulse ? ' fa-pulse' : '') + (state.border ? ' fa-border' : '') + (state.fixedWidth ? ' fa-fw' : '') + (state.inverse ? ' fa-inverse' : '') + (state.flip ? ' fa-flip-' + state.flip : '') + (state.rotate ? ' fa-rotate-' + state.rotate : '') + (state.stack ? ' fa-stack-' + state.stack : '') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(i, target, anchor);
		},

		p: function update(changed, state) {
			if ((changed.name || changed.size || changed.spin || changed.pulse || changed.border || changed.fixedWidth || changed.inverse || changed.flip || changed.rotate || changed.stack || changed.class) && i_class_value !== (i_class_value = "fa fa-" + state.name + (state.size ? ' fa-' + state.size : '') + (state.spin ? ' fa-spin' : '') + (state.pulse ? ' fa-pulse' : '') + (state.border ? ' fa-border' : '') + (state.fixedWidth ? ' fa-fw' : '') + (state.inverse ? ' fa-inverse' : '') + (state.flip ? ' fa-flip-' + state.flip : '') + (state.rotate ? ' fa-rotate-' + state.rotate : '') + (state.stack ? ' fa-stack-' + state.stack : '') + " " + state.class)) {
				i.className = i_class_value;
			}
		},

		u: function unmount() {
			detachNode(i);
		},

		d: noop
	};
}

function Icon(options) {
	init(this, options);
	this._state = assign(data$29(), options.data);

	this._fragment = create_main_fragment$30(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(Icon.prototype, proto);

/* src/InputGroup.html generated by Svelte v1.60.3 */
function data$30() {
  return {
    class: '',
    size: null
  }
}

function create_main_fragment$31(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "input-group" + (state.size ? ` input-group-${state.size}` : '') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.size || changed.class) && div_class_value !== (div_class_value = "input-group" + (state.size ? ` input-group-${state.size}` : '') + " " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function InputGroup(options) {
	init(this, options);
	this._state = assign(data$30(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$31(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(InputGroup.prototype, proto);

/* src/InputGroupAddon.html generated by Svelte v1.60.3 */
function data$31() {
  return {
    class: ''
  }
}

function create_main_fragment$32(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "input-group-addon " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && div_class_value !== (div_class_value = "input-group-addon " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function InputGroupAddon(options) {
	init(this, options);
	this._state = assign(data$31(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$32(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(InputGroupAddon.prototype, proto);

/* src/Jumbotron.html generated by Svelte v1.60.3 */
function data$32() {
  return {
    class: '',
    fluid: false
  }
}

function create_main_fragment$33(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "jumbotron" + (state.fluid ? ' jumbotron-fluid' : '') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.fluid || changed.class) && div_class_value !== (div_class_value = "jumbotron" + (state.fluid ? ' jumbotron-fluid' : '') + " " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function Jumbotron(options) {
	init(this, options);
	this._state = assign(data$32(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$33(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(Jumbotron.prototype, proto);

/* src/ListGroup.html generated by Svelte v1.60.3 */
function data$33() {
  return {
    class: '',
    flush: false
  }
}

function create_main_fragment$34(component, state) {
	var ul, slot_content_default = component._slotted.default, ul_class_value;

	return {
		c: function create() {
			ul = createElement("ul");
			this.h();
		},

		h: function hydrate() {
			ul.className = ul_class_value = "list-group" + (state.flush ? ' list-group-flush' : '') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(ul, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, ul);
			}
		},

		p: function update(changed, state) {
			if ((changed.flush || changed.class) && ul_class_value !== (ul_class_value = "list-group" + (state.flush ? ' list-group-flush' : '') + " " + state.class)) {
				ul.className = ul_class_value;
			}
		},

		u: function unmount() {
			detachNode(ul);

			if (slot_content_default) {
				reinsertChildren(ul, slot_content_default);
			}
		},

		d: noop
	};
}

function ListGroup(options) {
	init(this, options);
	this._state = assign(data$33(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$34(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(ListGroup.prototype, proto);

/* src/ListGroupItem.html generated by Svelte v1.60.3 */
function data$34() {
  return {
    active: false,
    class: '',
    disabled: false,
    action: false,
    color: false
  }
}

function create_main_fragment$35(component, state) {
	var li, slot_content_default = component._slotted.default, li_class_value;

	return {
		c: function create() {
			li = createElement("li");
			this.h();
		},

		h: function hydrate() {
			li.className = li_class_value = "list-group-item" + (state.active ? ' active' : '') + (state.disabled ? ' disabled' : '') + (state.action ? ' list-group-item-action' : '') + (state.color ? ` list-group-item-${state.color}` : '') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(li, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, li);
			}
		},

		p: function update(changed, state) {
			if ((changed.active || changed.disabled || changed.action || changed.color || changed.class) && li_class_value !== (li_class_value = "list-group-item" + (state.active ? ' active' : '') + (state.disabled ? ' disabled' : '') + (state.action ? ' list-group-item-action' : '') + (state.color ? ` list-group-item-${state.color}` : '') + " " + state.class)) {
				li.className = li_class_value;
			}
		},

		u: function unmount() {
			detachNode(li);

			if (slot_content_default) {
				reinsertChildren(li, slot_content_default);
			}
		},

		d: noop
	};
}

function ListGroupItem(options) {
	init(this, options);
	this._state = assign(data$34(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$35(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(ListGroupItem.prototype, proto);

/* src/ListGroupItemHeading.html generated by Svelte v1.60.3 */
function data$35() {
  return {
    class: ''
  }
}

function create_main_fragment$36(component, state) {
	var h5, slot_content_default = component._slotted.default, h5_class_value;

	return {
		c: function create() {
			h5 = createElement("h5");
			this.h();
		},

		h: function hydrate() {
			h5.className = h5_class_value = "list-group-item-heading " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(h5, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, h5);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && h5_class_value !== (h5_class_value = "list-group-item-heading " + state.class)) {
				h5.className = h5_class_value;
			}
		},

		u: function unmount() {
			detachNode(h5);

			if (slot_content_default) {
				reinsertChildren(h5, slot_content_default);
			}
		},

		d: noop
	};
}

function ListGroupItemHeading(options) {
	init(this, options);
	this._state = assign(data$35(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$36(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(ListGroupItemHeading.prototype, proto);

/* src/ListGroupItemText.html generated by Svelte v1.60.3 */
function data$36() {
  return {
    class: ''
  }
}

function create_main_fragment$37(component, state) {
	var p, slot_content_default = component._slotted.default, p_class_value;

	return {
		c: function create() {
			p = createElement("p");
			this.h();
		},

		h: function hydrate() {
			p.className = p_class_value = "list-group-item-text " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(p, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, p);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && p_class_value !== (p_class_value = "list-group-item-text " + state.class)) {
				p.className = p_class_value;
			}
		},

		u: function unmount() {
			detachNode(p);

			if (slot_content_default) {
				reinsertChildren(p, slot_content_default);
			}
		},

		d: noop
	};
}

function ListGroupItemText(options) {
	init(this, options);
	this._state = assign(data$36(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$37(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(ListGroupItemText.prototype, proto);

/* src/Media.html generated by Svelte v1.60.3 */
function data$37() {
  return {
    class: ''
  }
}

function create_main_fragment$38(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "media " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && div_class_value !== (div_class_value = "media " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function Media(options) {
	init(this, options);
	this._state = assign(data$37(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$38(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(Media.prototype, proto);

/* src/MediaBody.html generated by Svelte v1.60.3 */
function data$38() {
  return {
    class: ''
  }
}

function create_main_fragment$39(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "media-body " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && div_class_value !== (div_class_value = "media-body " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function MediaBody(options) {
	init(this, options);
	this._state = assign(data$38(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$39(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(MediaBody.prototype, proto);

/* src/ModalFooter.html generated by Svelte v1.60.3 */
function data$39() {
  return {
    class: ''
  }
}

function create_main_fragment$40(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "modal-footer " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && div_class_value !== (div_class_value = "modal-footer " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function ModalFooter(options) {
	init(this, options);
	this._state = assign(data$39(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$40(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(ModalFooter.prototype, proto);

/* src/NavDropdown.html generated by Svelte v1.60.3 */
function data$40() {
  return {
    class: ''
  }
}

function create_main_fragment$41(component, state) {
	var li, slot_content_default = component._slotted.default, li_class_value;

	return {
		c: function create() {
			li = createElement("li");
			this.h();
		},

		h: function hydrate() {
			li.className = li_class_value = "nav-item " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(li, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, li);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && li_class_value !== (li_class_value = "nav-item " + state.class)) {
				li.className = li_class_value;
			}
		},

		u: function unmount() {
			detachNode(li);

			if (slot_content_default) {
				reinsertChildren(li, slot_content_default);
			}
		},

		d: noop
	};
}

function NavDropdown(options) {
	init(this, options);
	this._state = assign(data$40(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$41(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(NavDropdown.prototype, proto);

/* src/Nav.html generated by Svelte v1.60.3 */
function data$41() {
  return {
    class: '',
    fill: false,
    justified: false,
    navbar: false,
    pills: false,
    tabs: false,
    vertical: false
  }
}

function create_main_fragment$42(component, state) {
	var ul, slot_content_default = component._slotted.default, ul_class_value;

	return {
		c: function create() {
			ul = createElement("ul");
			this.h();
		},

		h: function hydrate() {
			ul.className = ul_class_value = "" + (state.navbar ? 'navbar-nav' : 'nav') + (state.tabs ? ' nav-tabs' : '') + (state.pills ? ' nav-pills' : '') + (state.fill ? ' nav-fill' : state.justified ? ' nav-justified' : '') + (state.vertical ? ' flex-column' : '') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(ul, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, ul);
			}
		},

		p: function update(changed, state) {
			if ((changed.navbar || changed.tabs || changed.pills || changed.fill || changed.justified || changed.vertical || changed.class) && ul_class_value !== (ul_class_value = "" + (state.navbar ? 'navbar-nav' : 'nav') + (state.tabs ? ' nav-tabs' : '') + (state.pills ? ' nav-pills' : '') + (state.fill ? ' nav-fill' : state.justified ? ' nav-justified' : '') + (state.vertical ? ' flex-column' : '') + " " + state.class)) {
				ul.className = ul_class_value;
			}
		},

		u: function unmount() {
			detachNode(ul);

			if (slot_content_default) {
				reinsertChildren(ul, slot_content_default);
			}
		},

		d: noop
	};
}

function Nav(options) {
	init(this, options);
	this._state = assign(data$41(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$42(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(Nav.prototype, proto);

/* src/NavItem.html generated by Svelte v1.60.3 */
function data$42() {
  return {
    active: false,
    class: ''
  }
}

function create_main_fragment$43(component, state) {
	var li, slot_content_default = component._slotted.default, li_class_value;

	return {
		c: function create() {
			li = createElement("li");
			this.h();
		},

		h: function hydrate() {
			li.className = li_class_value = "nav-item" + (state.active ? ' active' : '') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(li, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, li);
			}
		},

		p: function update(changed, state) {
			if ((changed.active || changed.class) && li_class_value !== (li_class_value = "nav-item" + (state.active ? ' active' : '') + " " + state.class)) {
				li.className = li_class_value;
			}
		},

		u: function unmount() {
			detachNode(li);

			if (slot_content_default) {
				reinsertChildren(li, slot_content_default);
			}
		},

		d: noop
	};
}

function NavItem(options) {
	init(this, options);
	this._state = assign(data$42(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$43(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(NavItem.prototype, proto);

/* src/NavLink.html generated by Svelte v1.60.3 */
function data$43() {
  return {
    active: false,
    disabled: false,
    href: '#',
    class: ''
  }
}

function create_main_fragment$44(component, state) {
	var a, slot_content_default = component._slotted.default, a_class_value;

	function click_handler(event) {
		component.fire("click", event);
	}

	return {
		c: function create() {
			a = createElement("a");
			this.h();
		},

		h: function hydrate() {
			addListener(a, "click", click_handler);
			a.href = state.href;
			a.className = a_class_value = "nav-link" + (state.disabled ? ' disabled' : '') + (state.active ? ' active' : '') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(a, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, a);
			}
		},

		p: function update(changed, state) {
			if (changed.href) {
				a.href = state.href;
			}

			if ((changed.disabled || changed.active || changed.class) && a_class_value !== (a_class_value = "nav-link" + (state.disabled ? ' disabled' : '') + (state.active ? ' active' : '') + " " + state.class)) {
				a.className = a_class_value;
			}
		},

		u: function unmount() {
			detachNode(a);

			if (slot_content_default) {
				reinsertChildren(a, slot_content_default);
			}
		},

		d: function destroy$$1() {
			removeListener(a, "click", click_handler);
		}
	};
}

function NavLink(options) {
	init(this, options);
	this._state = assign(data$43(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$44(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(NavLink.prototype, proto);

/* src/NavbarBrand.html generated by Svelte v1.60.3 */
function data$44() {
  return {
    class: ''
  }
}

function create_main_fragment$45(component, state) {
	var a, slot_content_default = component._slotted.default, a_class_value;

	return {
		c: function create() {
			a = createElement("a");
			this.h();
		},

		h: function hydrate() {
			a.className = a_class_value = "navbar-brand " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(a, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, a);
			}
		},

		p: function update(changed, state) {
			if ((changed.class) && a_class_value !== (a_class_value = "navbar-brand " + state.class)) {
				a.className = a_class_value;
			}
		},

		u: function unmount() {
			detachNode(a);

			if (slot_content_default) {
				reinsertChildren(a, slot_content_default);
			}
		},

		d: noop
	};
}

function NavbarBrand(options) {
	init(this, options);
	this._state = assign(data$44(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$45(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(NavbarBrand.prototype, proto);

/* src/Pagination.html generated by Svelte v1.60.3 */
function data$45() {
  return {
    class: '',
    size: null
  }
}

function create_main_fragment$46(component, state) {
	var ul, slot_content_default = component._slotted.default, ul_class_value;

	return {
		c: function create() {
			ul = createElement("ul");
			this.h();
		},

		h: function hydrate() {
			ul.className = ul_class_value = "pagination" + (state.size ? ` pagination-${state.size}` : '') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(ul, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, ul);
			}
		},

		p: function update(changed, state) {
			if ((changed.size || changed.class) && ul_class_value !== (ul_class_value = "pagination" + (state.size ? ` pagination-${state.size}` : '') + " " + state.class)) {
				ul.className = ul_class_value;
			}
		},

		u: function unmount() {
			detachNode(ul);

			if (slot_content_default) {
				reinsertChildren(ul, slot_content_default);
			}
		},

		d: noop
	};
}

function Pagination(options) {
	init(this, options);
	this._state = assign(data$45(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$46(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(Pagination.prototype, proto);

/* src/PaginationItem.html generated by Svelte v1.60.3 */
function data$46() {
  return {
    active: false,
    class: '',
    disabled: false
  }
}

function create_main_fragment$47(component, state) {
	var li, slot_content_default = component._slotted.default, li_class_value;

	return {
		c: function create() {
			li = createElement("li");
			this.h();
		},

		h: function hydrate() {
			li.className = li_class_value = "page-item" + (state.active ? ' active' : '') + (state.disabled ? ' disabled' : '') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(li, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, li);
			}
		},

		p: function update(changed, state) {
			if ((changed.active || changed.disabled || changed.class) && li_class_value !== (li_class_value = "page-item" + (state.active ? ' active' : '') + (state.disabled ? ' disabled' : '') + " " + state.class)) {
				li.className = li_class_value;
			}
		},

		u: function unmount() {
			detachNode(li);

			if (slot_content_default) {
				reinsertChildren(li, slot_content_default);
			}
		},

		d: noop
	};
}

function PaginationItem(options) {
	init(this, options);
	this._state = assign(data$46(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$47(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(PaginationItem.prototype, proto);

/* src/PaginationLink.html generated by Svelte v1.60.3 */
// TODO add state to this component, generate PaginationItems, Links, on:click, etc
function data$47() {
  return {
    class: '',
    next: false,
    previous: false
  }
}

function create_main_fragment$48(component, state) {
	var a, a_class_value;

	function select_block_type(state) {
		if (state.previous) return create_if_block$1;
		if (state.next) return create_if_block_1$1;
		return create_if_block_2;
	}

	var current_block_type = select_block_type(state);
	var if_block = current_block_type(component, state);

	function click_handler(event) {
		component.fire("click", event);
	}

	return {
		c: function create() {
			a = createElement("a");
			if_block.c();
			this.h();
		},

		h: function hydrate() {
			addListener(a, "click", click_handler);
			a.className = a_class_value = "page-link" + (state.size ? ` pagination-${state.size}` : '') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(a, target, anchor);
			if_block.m(a, null);
		},

		p: function update(changed, state) {
			if (current_block_type !== (current_block_type = select_block_type(state))) {
				if_block.u();
				if_block.d();
				if_block = current_block_type(component, state);
				if_block.c();
				if_block.m(a, null);
			}

			if ((changed.size || changed.class) && a_class_value !== (a_class_value = "page-link" + (state.size ? ` pagination-${state.size}` : '') + " " + state.class)) {
				a.className = a_class_value;
			}
		},

		u: function unmount() {
			detachNode(a);
			if_block.u();
		},

		d: function destroy$$1() {
			if_block.d();
			removeListener(a, "click", click_handler);
		}
	};
}

// (5:2) {{#if previous}}
function create_if_block$1(component, state) {
	var text;

	return {
		c: function create() {
			text = createText("«");
		},

		m: function mount(target, anchor) {
			insertNode(text, target, anchor);
		},

		u: function unmount() {
			detachNode(text);
		},

		d: noop
	};
}

// (7:17) 
function create_if_block_1$1(component, state) {
	var text;

	return {
		c: function create() {
			text = createText("»");
		},

		m: function mount(target, anchor) {
			insertNode(text, target, anchor);
		},

		u: function unmount() {
			detachNode(text);
		},

		d: noop
	};
}

// (9:2) {{else}}
function create_if_block_2(component, state) {
	var slot_content_default = component._slotted.default, slot_content_default_before, slot_content_default_after;

	return {
		c: noop,

		m: function mount(target, anchor) {
			if (slot_content_default) {
				insertNode(slot_content_default_before || (slot_content_default_before = createComment()), target, anchor);
				insertNode(slot_content_default, target, anchor);
				insertNode(slot_content_default_after || (slot_content_default_after = createComment()), target, anchor);
			}
		},

		u: function unmount() {
			if (slot_content_default) {
				reinsertBetween(slot_content_default_before, slot_content_default_after, slot_content_default);
				detachNode(slot_content_default_before);
				detachNode(slot_content_default_after);
			}
		},

		d: noop
	};
}

function PaginationLink(options) {
	init(this, options);
	this._state = assign(data$47(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$48(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(PaginationLink.prototype, proto);

/**
 * lodash (Custom Build) <https://lodash.com/>
 * Build: `lodash modularize exports="npm" -o ./`
 * Copyright jQuery Foundation and other contributors <https://jquery.org/>
 * Released under MIT license <https://lodash.com/license>
 * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
 * Copyright Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
 */

/** Used as references for various `Number` constants. */
var NAN = 0 / 0;

/** `Object#toString` result references. */
var symbolTag = '[object Symbol]';

/** Used to match leading and trailing whitespace. */
var reTrim = /^\s+|\s+$/g;

/** Used to detect bad signed hexadecimal string values. */
var reIsBadHex = /^[-+]0x[0-9a-f]+$/i;

/** Used to detect binary string values. */
var reIsBinary = /^0b[01]+$/i;

/** Used to detect octal string values. */
var reIsOctal = /^0o[0-7]+$/i;

/** Built-in method references without a dependency on `root`. */
var freeParseInt = parseInt;

/** Used for built-in method references. */
var objectProto = Object.prototype;

/**
 * Used to resolve the
 * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
 * of values.
 */
var objectToString = objectProto.toString;

/**
 * Checks if `value` is the
 * [language type](http://www.ecma-international.org/ecma-262/7.0/#sec-ecmascript-language-types)
 * of `Object`. (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an object, else `false`.
 * @example
 *
 * _.isObject({});
 * // => true
 *
 * _.isObject([1, 2, 3]);
 * // => true
 *
 * _.isObject(_.noop);
 * // => true
 *
 * _.isObject(null);
 * // => false
 */
function isObject$1(value) {
  var type = typeof value;
  return !!value && (type == 'object' || type == 'function');
}

/**
 * Checks if `value` is object-like. A value is object-like if it's not `null`
 * and has a `typeof` result of "object".
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
 * @example
 *
 * _.isObjectLike({});
 * // => true
 *
 * _.isObjectLike([1, 2, 3]);
 * // => true
 *
 * _.isObjectLike(_.noop);
 * // => false
 *
 * _.isObjectLike(null);
 * // => false
 */
function isObjectLike(value) {
  return !!value && typeof value == 'object';
}

/**
 * Checks if `value` is classified as a `Symbol` primitive or object.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a symbol, else `false`.
 * @example
 *
 * _.isSymbol(Symbol.iterator);
 * // => true
 *
 * _.isSymbol('abc');
 * // => false
 */
function isSymbol(value) {
  return typeof value == 'symbol' ||
    (isObjectLike(value) && objectToString.call(value) == symbolTag);
}

/**
 * Converts `value` to a number.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to process.
 * @returns {number} Returns the number.
 * @example
 *
 * _.toNumber(3.2);
 * // => 3.2
 *
 * _.toNumber(Number.MIN_VALUE);
 * // => 5e-324
 *
 * _.toNumber(Infinity);
 * // => Infinity
 *
 * _.toNumber('3.2');
 * // => 3.2
 */
function toNumber$1(value) {
  if (typeof value == 'number') {
    return value;
  }
  if (isSymbol(value)) {
    return NAN;
  }
  if (isObject$1(value)) {
    var other = typeof value.valueOf == 'function' ? value.valueOf() : value;
    value = isObject$1(other) ? (other + '') : other;
  }
  if (typeof value != 'string') {
    return value === 0 ? value : +value;
  }
  value = value.replace(reTrim, '');
  var isBinary = reIsBinary.test(value);
  return (isBinary || reIsOctal.test(value))
    ? freeParseInt(value.slice(2), isBinary ? 2 : 8)
    : (reIsBadHex.test(value) ? NAN : +value);
}

var index = toNumber$1;

/* src/Progress.html generated by Svelte v1.60.3 */
function percent(value, max) {
  return (index(value) / index(max)) * 100;
}

function data$48() {
  return {
    bar: false,
    class: '',
    value: 0,
    max: 100,
    multi: false
  }
}

function create_main_fragment$49(component, state) {
	var if_block_anchor;

	function select_block_type_1(state) {
		if (!state.bar) return create_if_block$2;
		return create_if_block_3;
	}

	var current_block_type = select_block_type_1(state);
	var if_block = current_block_type(component, state);

	return {
		c: function create() {
			if_block.c();
			if_block_anchor = createComment();
		},

		m: function mount(target, anchor) {
			if_block.m(target, anchor);
			insertNode(if_block_anchor, target, anchor);
		},

		p: function update(changed, state) {
			if (current_block_type === (current_block_type = select_block_type_1(state)) && if_block) {
				if_block.p(changed, state);
			} else {
				if_block.u();
				if_block.d();
				if_block = current_block_type(component, state);
				if_block.c();
				if_block.m(if_block_anchor.parentNode, if_block_anchor);
			}
		},

		u: function unmount() {
			if_block.u();
			detachNode(if_block_anchor);
		},

		d: function destroy$$1() {
			if_block.d();
		}
	};
}

// (3:4) {{#if multi}}
function create_if_block_1$2(component, state) {
	var slot_content_default = component._slotted.default, slot_content_default_before, slot_content_default_after;

	return {
		c: noop,

		m: function mount(target, anchor) {
			if (slot_content_default) {
				insertNode(slot_content_default_before || (slot_content_default_before = createComment()), target, anchor);
				insertNode(slot_content_default, target, anchor);
				insertNode(slot_content_default_after || (slot_content_default_after = createComment()), target, anchor);
			}
		},

		p: noop,

		u: function unmount() {
			if (slot_content_default) {
				reinsertBetween(slot_content_default_before, slot_content_default_after, slot_content_default);
				detachNode(slot_content_default_before);
				detachNode(slot_content_default_after);
			}
		},

		d: noop
	};
}

// (5:4) {{else}}
function create_if_block_2$1(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "progress-bar" + (state.animated ? ' progress-bar-animated' : '') + (state.color ? ` bg-${state.color}` : '') + (state.striped || state.animated ? ' progress-bar-striped' : '');
			setStyle(div, "width", "" + state.percent + "%");
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.animated || changed.color || changed.striped) && div_class_value !== (div_class_value = "progress-bar" + (state.animated ? ' progress-bar-animated' : '') + (state.color ? ` bg-${state.color}` : '') + (state.striped || state.animated ? ' progress-bar-striped' : ''))) {
				div.className = div_class_value;
			}

			if (changed.percent) {
				setStyle(div, "width", "" + state.percent + "%");
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

// (1:0) {{#if !bar}}
function create_if_block$2(component, state) {
	var div, div_class_value;

	function select_block_type(state) {
		if (state.multi) return create_if_block_1$2;
		return create_if_block_2$1;
	}

	var current_block_type = select_block_type(state);
	var if_block = current_block_type(component, state);

	return {
		c: function create() {
			div = createElement("div");
			if_block.c();
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "progress " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);
			if_block.m(div, null);
		},

		p: function update(changed, state) {
			if (current_block_type === (current_block_type = select_block_type(state)) && if_block) {
				if_block.p(changed, state);
			} else {
				if_block.u();
				if_block.d();
				if_block = current_block_type(component, state);
				if_block.c();
				if_block.m(div, null);
			}

			if ((changed.class) && div_class_value !== (div_class_value = "progress " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);
			if_block.u();
		},

		d: function destroy$$1() {
			if_block.d();
		}
	};
}

// (14:0) {{else}}
function create_if_block_3(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "progress-bar" + (state.animated ? ' progress-bar-animated' : '') + (state.color ? ` bg-${state.color}` : '') + (state.striped || state.animated ? ' progress-bar-striped' : '');
			setStyle(div, "width", "" + state.percent + "%");
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.animated || changed.color || changed.striped) && div_class_value !== (div_class_value = "progress-bar" + (state.animated ? ' progress-bar-animated' : '') + (state.color ? ` bg-${state.color}` : '') + (state.striped || state.animated ? ' progress-bar-striped' : ''))) {
				div.className = div_class_value;
			}

			if (changed.percent) {
				setStyle(div, "width", "" + state.percent + "%");
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function Progress(options) {
	init(this, options);
	this._state = assign(data$48(), options.data);
	this._recompute({ value: 1, max: 1 }, this._state);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$49(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(Progress.prototype, proto);

Progress.prototype._recompute = function _recompute(changed, state) {
	if (changed.value || changed.max) {
		if (this._differs(state.percent, (state.percent = percent(state.value, state.max)))) changed.percent = true;
	}
};

/* src/Row.html generated by Svelte v1.60.3 */
function data$49() {
  return {
    class: '',
    noGutters: false
  }
}

function create_main_fragment$50(component, state) {
	var div, slot_content_default = component._slotted.default, div_class_value;

	return {
		c: function create() {
			div = createElement("div");
			this.h();
		},

		h: function hydrate() {
			div.className = div_class_value = "row" + (state.noGutters ? ' no-gutters' : '') + " " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, div);
			}
		},

		p: function update(changed, state) {
			if ((changed.noGutters || changed.class) && div_class_value !== (div_class_value = "row" + (state.noGutters ? ' no-gutters' : '') + " " + state.class)) {
				div.className = div_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(div, slot_content_default);
			}
		},

		d: noop
	};
}

function Row(options) {
	init(this, options);
	this._state = assign(data$49(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$50(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(Row.prototype, proto);

/* src/Table.html generated by Svelte v1.60.3 */
// TODO remove duplication of table above
function data$50() {
  return {
    class: '',
    size: null,
    bordered: false,
    striped: false,
    inverse: false,
    hover: false,
    reflow: false
  }
}

function create_main_fragment$51(component, state) {
	var if_block_anchor;

	function select_block_type(state) {
		if (state.responsive) return create_if_block$3;
		return create_if_block_1$3;
	}

	var current_block_type = select_block_type(state);
	var if_block = current_block_type(component, state);

	return {
		c: function create() {
			if_block.c();
			if_block_anchor = createComment();
		},

		m: function mount(target, anchor) {
			if_block.m(target, anchor);
			insertNode(if_block_anchor, target, anchor);
		},

		p: function update(changed, state) {
			if (current_block_type === (current_block_type = select_block_type(state)) && if_block) {
				if_block.p(changed, state);
			} else {
				if_block.u();
				if_block.d();
				if_block = current_block_type(component, state);
				if_block.c();
				if_block.m(if_block_anchor.parentNode, if_block_anchor);
			}
		},

		u: function unmount() {
			if_block.u();
			detachNode(if_block_anchor);
		},

		d: function destroy$$1() {
			if_block.d();
		}
	};
}

// (1:0) {{#if responsive}}
function create_if_block$3(component, state) {
	var div, table, slot_content_default = component._slotted.default, table_class_value;

	return {
		c: function create() {
			div = createElement("div");
			table = createElement("table");
			this.h();
		},

		h: function hydrate() {
			table.className = table_class_value = "table" + (state.size ? ` table-${state.size}` : '') + (state.bordered ? ' table-bordered' : '') + (state.striped ? ' table-striped' : '') + (state.inverse ? ' table-inverse' : '') + (state.hover ? ' table-hover' : '') + (state.reflow ? ' table-reflow' :'') + "\n   " + state.class;
			div.className = "table-responsive";
		},

		m: function mount(target, anchor) {
			insertNode(div, target, anchor);
			appendNode(table, div);

			if (slot_content_default) {
				appendNode(slot_content_default, table);
			}
		},

		p: function update(changed, state) {
			if ((changed.size || changed.bordered || changed.striped || changed.inverse || changed.hover || changed.reflow || changed.class) && table_class_value !== (table_class_value = "table" + (state.size ? ` table-${state.size}` : '') + (state.bordered ? ' table-bordered' : '') + (state.striped ? ' table-striped' : '') + (state.inverse ? ' table-inverse' : '') + (state.hover ? ' table-hover' : '') + (state.reflow ? ' table-reflow' :'') + "\n   " + state.class)) {
				table.className = table_class_value;
			}
		},

		u: function unmount() {
			detachNode(div);

			if (slot_content_default) {
				reinsertChildren(table, slot_content_default);
			}
		},

		d: noop
	};
}

// (8:0) {{else}}
function create_if_block_1$3(component, state) {
	var table, slot_content_default = component._slotted.default, table_class_value;

	return {
		c: function create() {
			table = createElement("table");
			this.h();
		},

		h: function hydrate() {
			table.className = table_class_value = "table" + (state.size ? ` table-${state.size}` : '') + (state.bordered ? ' table-bordered' : '') + (state.striped ? ' table-striped' : '') + (state.inverse ? ' table-inverse' : '') + (state.hover ? ' table-hover' : '') + (state.reflow ? ' table-reflow' :'') + "\n   " + state.class;
		},

		m: function mount(target, anchor) {
			insertNode(table, target, anchor);

			if (slot_content_default) {
				appendNode(slot_content_default, table);
			}
		},

		p: function update(changed, state) {
			if ((changed.size || changed.bordered || changed.striped || changed.inverse || changed.hover || changed.reflow || changed.class) && table_class_value !== (table_class_value = "table" + (state.size ? ` table-${state.size}` : '') + (state.bordered ? ' table-bordered' : '') + (state.striped ? ' table-striped' : '') + (state.inverse ? ' table-inverse' : '') + (state.hover ? ' table-hover' : '') + (state.reflow ? ' table-reflow' :'') + "\n   " + state.class)) {
				table.className = table_class_value;
			}
		},

		u: function unmount() {
			detachNode(table);

			if (slot_content_default) {
				reinsertChildren(table, slot_content_default);
			}
		},

		d: noop
	};
}

function Table(options) {
	init(this, options);
	this._state = assign(data$50(), options.data);

	this._slotted = options.slots || {};

	this.slots = {};

	this._fragment = create_main_fragment$51(this, this._state);

	if (options.target) {
		this._fragment.c();
		this._mount(options.target, options.anchor);
	}
}

assign(Table.prototype, proto);

exports.Alert = Alert;
exports.Badge = Badge;
exports.Breadcrumb = Breadcrumb;
exports.BreadcrumbItem = BreadcrumbItem;
exports.Button = Button;
exports.ButtonGroup = ButtonGroup;
exports.ButtonToolbar = ButtonToolbar;
exports.Card = Card;
exports.CardBody = CardBody;
exports.CardColumns = CardColumns;
exports.CardDeck = CardDeck;
exports.CardFooter = CardFooter;
exports.CardGroup = CardGroup;
exports.CardHeader = CardHeader;
exports.CardImgOverlay = CardImgOverlay;
exports.CardSubtitle = CardSubtitle;
exports.CardText = CardText;
exports.CardTitle = CardTitle;
exports.Close = Close;
exports.Col = Col;
exports.Container = Container;
exports.Dropdown = Dropdown;
exports.DropdownDivider = DropdownDivider;
exports.DropdownHeader = DropdownHeader;
exports.DropdownItem = DropdownItem;
exports.DropdownMenu = DropdownMenu;
exports.Form = Form;
exports.FormFeedback = FormFeedback;
exports.FormGroup = FormGroup;
exports.FormText = FormText;
exports.Icon = Icon;
exports.InputGroup = InputGroup;
exports.InputGroupAddon = InputGroupAddon;
exports.Jumbotron = Jumbotron;
exports.ListGroup = ListGroup;
exports.ListGroupItem = ListGroupItem;
exports.ListGroupItemHeading = ListGroupItemHeading;
exports.ListGroupItemText = ListGroupItemText;
exports.Media = Media;
exports.MediaBody = MediaBody;
exports.ModalFooter = ModalFooter;
exports.NavDropdown = NavDropdown;
exports.Nav = Nav;
exports.NavItem = NavItem;
exports.NavLink = NavLink;
exports.NavbarBrand = NavbarBrand;
exports.Pagination = Pagination;
exports.PaginationItem = PaginationItem;
exports.PaginationLink = PaginationLink;
exports.Progress = Progress;
exports.Row = Row;
exports.Table = Table;
